#
# spec file for package python-calver
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -%{flavor}
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define skip_python2 1
%define ghtag 2022.06.26
%{?sle15_python_module_pythons}
Name:           python-calver%{psuffix}
Version:        2025.4.17
Release:        1.1
Summary:        Setuptools extension for CalVer package versions
License:        Apache-2.0
URL:            https://github.com/di/calver
Source:         https://github.com/di/calver/archive/refs/tags/%{ghtag}.tar.gz#/calver-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirement
%if %{with test}
BuildRequires:  %{python_module calver}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest}
%endif
# /SECTION
%python_subpackages

%description
Setuptools extension for CalVer package versions

%prep
%setup -q -n calver-%{ghtag}
# We use the github archive because it has the tests. However, it will produce a dynamic calver version of today.
# We don't want that.
sed -i 's/calver_version(True)/"%{version}"/' setup.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/calver
%{python_sitelib}/calver-%{version}*-info
%endif

%changelog
* Fri May 23 2025 Dirk Müller <dmueller@suse.com>
- update to 2025.04.17:
  * test: Delete SOURCE_DATE_EPOCH envvar if already present for
    robustness
- update to 2025.04.02:
  * Update build backend
  * Support running tests from source distribution
- update to 2025.04.01:
  * Switch to `pyproject.toml` as much as possible
- update to 2025.03.31:
  * Support Python 3.11, test 3.12-dev, drop EOL 3.5-3.6
  * Update release.yml to use OIDC publishing
  * Drop 3.7 and 3.8
  * Support SOURCE_DATE_EPOCH for reproducible builds
* Thu May 15 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 20 2023 Steve Kowalik <steven.kowalik@suse.com>
- Inject multibuild.
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v2022.6.26
- Required by trove-classifiers
